%define pkgname gnupg

Summary:	GNU privacy guard - a free PGP replacement
Name:		gnupg2
Version:	2.0.22
%define subrel	2
Release:	%mkrel 3
License:	GPLv3+
Group:		File tools
URL:		http://www.gnupg.org
Source0:	ftp://ftp.gnupg.org/gcrypt/gnupg/%{pkgname}-%{version}.tar.bz2
Source1:	ftp://ftp.gnupg.org/gcrypt/gnupg/%{pkgname}-%{version}.tar.bz2.sig
Source2:	gpg-agent.sh
Source3:	gpg-agent-xinit.sh
Source4:	sysconfig-gnupg2
Patch0:		gnupg-1.9.3-use-ImageMagick-for-photo.patch
Patch1:		gnupg-2.0.22-CVE-2014-4617.patch
Patch2:		gnupg-2.0.26-null-deref-1.patch
Patch3:		gnupg-2.0.26-null-deref-2.patch
Patch4:		gnupg-2.0.22-CVE-2015-1606.patch
Patch5:		gnupg-2.0.22-CVE-2015-1607.patch

BuildRequires:	openldap-devel
BuildRequires:	sendmail-command
BuildRequires:	libgpg-error-devel >= 1.11
BuildRequires:	libgcrypt-devel >= 1.4.0
BuildRequires:	libassuan-devel >= 2.0.0
BuildRequires:	libksba-devel >= 1.0.7
BuildRequires:	zlib-devel
BuildRequires:	pth-devel >= 2.0.0
BuildRequires:	docbook-utils
BuildRequires:	libreadline-devel
BuildRequires:	libtermcap-devel
BuildRequires:	libcurl-devel
BuildRequires:	libusb-devel
BuildRequires:	bzip2-devel
BuildRequires:	libassuan-devel
Requires(post):	info-install
Requires(preun): info-install
Requires:	info-install
Requires:	dirmngr
Requires:	pinentry
Requires:	gnupg
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot

%description
GnuPG is GNU's tool for secure communication and data storage.
It can be used to encrypt data and to create digital signatures.
It includes an advanced key management facility and is compliant
with the proposed OpenPGP Internet standard as described in RFC2440.

%prep
%setup -q -n %{pkgname}-%{version}
%patch0 -p1 -b .ImageMagick
%patch1 -p1 -b .CVE-2014-4617
%patch2 -p1 -b .null-deref-1
%patch3 -p1 -b .null-deref-2
%patch4 -p1 -b .CVE-2015-1606
%patch5 -p1 -b .CVE-2015-1607

%build
%serverbuild

./autogen.sh

%configure2_5x \
	--libexecdir=%{_libdir}/gnupg2 \
	--enable-symcryptrun \
	--disable-rpath \
	--without-capabilities \
	--with-adns=no \
	--with-pkits-tests

# no parallel make (v2.0.5 at least)
%make

# all tests must pass on i586 and x86_64
%check
[[ -n "$GPG_AGENT_INFO" ]] || eval `./agent/gpg-agent --use-standard-socket --daemon --write-env-file gpg-agent-info`
make check
[[ -a gpg-agent-info ]] && kill -0 `cut -d: -f 2 gpg-agent-info`
rm -f gpg-agent-info

%install
rm -rf %{buildroot}

%makeinstall_std
#Remove: #60298
install -d %{buildroot}/%{_sysconfdir}/profile.d
install %{SOURCE2} %{buildroot}/%{_sysconfdir}/profile.d/gpg-agent.sh
install -d %{buildroot}/%{_sysconfdir}/X11/xinit.d
install %{SOURCE3} %{buildroot}/%{_sysconfdir}/X11/xinit.d/gpg-agent
install -d %{buildroot}/%{_sysconfdir}/sysconfig
install %{SOURCE4} %{buildroot}/%{_sysconfdir}/sysconfig/%{name}

# remove this from package because the content of options.skel is the
# identical for both gnupg 1/2, except for comment
rm -rf %{buildroot}%{_datadir}/gnupg

rm -rf %{buildroot}%{_docdir}/gnupg

# fix file conflict with 'gnupg' package
rm %{buildroot}%{_mandir}/man1/gpg-zip.1

%find_lang %{name}

%post
%_install_info gnupg.info

%preun
%_remove_install_info gnupg.info

%clean
rm -rf %{buildroot}

%files -f %{name}.lang
%defattr(-,root,root)
%doc README NEWS THANKS TODO ChangeLog
%doc doc/FAQ doc/HACKING doc/KEYSERVER doc/OpenPGP doc/TRANSLATE doc/DETAILS
%doc doc/examples
%attr(0755,root,root) %{_sysconfdir}/profile.d/gpg-agent.sh
%attr(0755,root,root) %{_sysconfdir}/X11/xinit.d/gpg-agent
%attr(0644,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%attr(4755,root,root) %{_bindir}/gpgsm
%{_bindir}/gpg-agent
%{_bindir}/gpgconf
%{_bindir}/kbxutil
%{_bindir}/watchgnupg
%{_bindir}/gpgsm-gencert.sh
%{_bindir}/gpgkey2ssh
%{_bindir}/gpg-connect-agent
%{_bindir}/gpgparsemail
%{_bindir}/gpg2
%{_bindir}/gpgv2
%{_bindir}/symcryptrun
%{_sbindir}/addgnupghome
%{_sbindir}/applygnupgdefaults
%dir %{_libdir}/gnupg2
%{_libdir}/gnupg2/gpg-check-pattern
%{_libdir}/gnupg2/gpg-preset-passphrase
%{_libdir}/gnupg2/gpg-protect-tool
%{_libdir}/gnupg2/gnupg-pcsc-wrapper
%{_libdir}/gnupg2/gpg2keys_curl
%{_libdir}/gnupg2/gpg2keys_finger
%{_libdir}/gnupg2/gpg2keys_hkp
%{_libdir}/gnupg2/gpg2keys_ldap
%{_libdir}/gnupg2/scdaemon
%{_infodir}/gnupg.info*
%{_mandir}/man1/gpg-agent.1*
%{_mandir}/man1/gpg-connect-agent.1*
%{_mandir}/man1/gpg-preset-passphrase.1*
%{_mandir}/man1/gpg2.1*
%{_mandir}/man1/gpgconf.1*
%{_mandir}/man1/gpgparsemail.1*
%{_mandir}/man1/gpgsm-gencert.sh.1*
%{_mandir}/man1/gpgsm.1*
%{_mandir}/man1/gpgv2.1*
%{_mandir}/man1/scdaemon.1*
%{_mandir}/man1/symcryptrun.1*
%{_mandir}/man1/watchgnupg.1*
%{_mandir}/man8/addgnupghome.8*
%{_mandir}/man8/applygnupgdefaults.8*




%changelog
* Fri Mar 13 2015 luigiwalser <luigiwalser> 2.0.22-3.2.mga4
+ Revision: 818484
- rediff upstream patches to fix some minor issues including CVE-2015-160[67]
- add upstream patch to fix CVE-2014-4617

* Thu Jan 09 2014 dmorgan <dmorgan> 2.0.22-3.mga4
+ Revision: 565758
- Rebuild to please autobuild

* Mon Oct 21 2013 umeabot <umeabot> 2.0.22-2.mga4
+ Revision: 539521
- Mageia 4 Mass Rebuild

* Mon Oct 07 2013 fwang <fwang> 2.0.22-1.mga4
+ Revision: 492375
- new version 2.0.22

* Mon Sep 30 2013 oden <oden> 2.0.21-2.mga4
+ Revision: 489449
- P1: security fix for CVE-2013-4351 (opensuse)

* Tue Aug 20 2013 fwang <fwang> 2.0.21-1.mga4
+ Revision: 468236
- new version 2.0.21

* Thu Jun 27 2013 fwang <fwang> 2.0.20-1.mga4
+ Revision: 447354
- update file list
- update file list
- new version 2.0.20

* Sat Jan 12 2013 umeabot <umeabot> 2.0.19-3.mga3
+ Revision: 352373
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Jan 02 2013 oden <oden> 2.0.19-2.mga3
+ Revision: 337608
- P2: security fix for CVE-2012-6085 (upstream)

* Thu Jul 12 2012 solbu <solbu> 2.0.19-1.mga3
+ Revision: 269615
- Fix License tag
- Remove 8-years old obsolete
- New version

* Fri Jun 22 2012 boklm <boklm> 2.0.18-2.mga3
+ Revision: 262622
- remove test on non-empty /etc/mtab file (from Dave Hodgins, fixing bug #5360)

* Fri Aug 05 2011 fwang <fwang> 2.0.18-1.mga2
+ Revision: 131851
- new version 2.0.18
- new version 2.0.17

* Sat Jan 15 2011 mikala <mikala> 2.0.16-6.mga1
+ Revision: 18603
- imported package gnupg2

